#
# spec file for package libgme
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 0

Name:           libgme
Version:        0.6.0
Release:        6.4
Summary:        Collection of video game music file emulators
License:        LGPL-2.1+
Group:          System/Libraries
Url:            http://code.google.com/p/game-music-emu/
Source0:        http://game-music-emu.googlecode.com/files/game-music-emu-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM libgme-0.6.0-pkgconfig_path.patch http://code.google.com/p/game-music-emu/issues/detail?id=19 reddwarf@opensuse.org -- Fix .pc installation path
Patch0:         libgme-0.6.0-pkgconfig_path.patch
# See http://code.google.com/p/game-music-emu/issues/detail?id=19 for the overflow/underflow warnings
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkg-config

%description
Game_Music_Emu is a collection of video game music file emulators that support
the following formats and systems:
- AY: ZX Spectrum/Amstrad CPC
- GBS: Nintendo Game Boy
- GYM: Sega Genesis/Mega Drive
- HES: NEC TurboGrafx-16/PC Engine
- KSS: MSX Home Computer/other Z80 systems (doesn't support FM sound)
- NSF/NSFE: Nintendo NES/Famicom (with VRC 6, Namco 106, and FME-7 sound)
- SAP: Atari systems using POKEY sound chip
- SPC: Super Nintendo/Super Famicom
- VGM/VGZ: Sega Master System/Mark III, Sega Genesis/Mega Drive,BBC Micro

%package -n libgme%{soname}

Summary:        Collection of video game music file emulators
Group:          System/Libraries

%description -n libgme%{soname}
Game_Music_Emu is a collection of video game music file emulators that support
the following formats and systems:
- AY: ZX Spectrum/Amstrad CPC
- GBS: Nintendo Game Boy
- GYM: Sega Genesis/Mega Drive
- HES: NEC TurboGrafx-16/PC Engine
- KSS: MSX Home Computer/other Z80 systems (doesn't support FM sound)
- NSF/NSFE: Nintendo NES/Famicom (with VRC 6, Namco 106, and FME-7 sound)
- SAP: Atari systems using POKEY sound chip
- SPC: Super Nintendo/Super Famicom
- VGM/VGZ: Sega Master System/Mark III, Sega Genesis/Mega Drive,BBC Micro

%package devel
Summary:        Development libraries and headers for libgme
Group:          Development/Libraries/C and C++
Requires:       libgme%{soname} = %{version}

%description devel
The developmental files that must be installed in order to compile applications
which use libgme.

%prep
%setup -q -n game-music-emu-%{version}
%patch0
sed -i 's/\r$//' changes.txt design.txt gme.txt license.txt readme.txt

%build
export CFLAGS='%{optflags}'
export CXXFLAGS='%{optflags}'
mkdir build
cd build
cmake -DCMAKE_SKIP_RPATH=1 \
      -DCMAKE_INSTALL_PREFIX=%{_prefix} \
      -DLIB_SUFFIX=$(echo %{_lib} | cut -b4-) \
      -DCMAKE_BUILD_TYPE=Release ..
make %{?_smp_mflags} VERBOSE=1

%install
cd build
%make_install

%post -n libgme%{soname} -p /sbin/ldconfig

%postun -n libgme%{soname} -p /sbin/ldconfig

%files -n libgme%{soname}
%defattr(0644, root, root, 0755)
%doc changes.txt gme.txt license.txt readme.txt
%{_libdir}/libgme.so.%{soname}*

%files devel
%defattr(0644, root, root, 0755)
%doc design.txt
%{_includedir}/gme
%{_libdir}/libgme.so
%{_libdir}/pkgconfig/libgme.pc

%changelog
* Sun Mar 17 2013 reddwarf@opensuse.org
- Update to 0.6.0
  * SPC improvements:
  - Switched to newer snes_spc 0.9.0 for SPC emulation. Uses fast DSP.
  - Fixed Spc_Emu::gain().
  - Fixed support for files <0x10200 bytes.
  * Other bugfixes:
  - Fixed a couple of GBS bugs, one involving access of memory after
    realloc.
  - Blip_Buffer works on systems where 'double' is a single-precision
    floating-point type.
  - Fix uninitialized buffer size in dual_resampler.
  - Compilation warnings squashed out as of clang 3.3-pre and gcc 4.7.2.
  * API changes/additions:
  - Removed documentation of C++ interface, as the C interface in gme.h is
    the only supported one.
  - Added gme_enable_accuracy() for enabling more accurate sound emulation
    options (currently affects SPC only).
  * Build system improvements:
  - Add pkg_config support.
  - Fix build on case-insensitive systems.
  - Allow for install on Cygwin.
  - Fix install on multilib systems, such as many 64-bit distros (CMake must
    be able to figure out your system's libsuffix, if any).
  - C++ implementation symbols are not leaked into the resultant library
    file (requires symbol visibility support).
  * Sample player improvements:
  - Can toggle fast/accurate emulation (with the 'A' key).
- Remove all the previous patches (libgme-0.5.5-LIB_SUFFIX.patch,
  libgme-0.5.5-pkg_config.patch and libgme-0.5.5-symbol_visibility.patch)
- Add libgme-0.6.0-pkgconfig_path.patch
* Tue May  3 2011 reddwarf@opensuse.org
- Update libgme-0.5.5-symbol_visibility.patch to not install
  headers for functions that are not exported.
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
- Escaped macros in comments (fix for RPMLINT warning)
* Tue Dec 14 2010 reddwarf@opensuse.org
- Initial package
